Github messages for voidlinux
 help / color / mirror / Atom feed
From: TinfoilSubmarine <TinfoilSubmarine@users.noreply.github.com>
To: ml@inbox.vuxu.org
Subject: Re: [PR PATCH] [Updated] [WIP] synapse: update to 1.68.0rc1.
Date: Thu, 22 Sep 2022 16:30:26 +0200	[thread overview]
Message-ID: <20220922143026.eVHuaacIDc0Ug9i2ym5cOYlqvMO_XJeJMzw_Mw8SJWg@z> (raw)
In-Reply-To: <gh-mailinglist-notifications-41a7ca26-5023-4802-975b-f1789d68868e-void-packages-39416@inbox.vuxu.org>

[-- Attachment #1: Type: text/plain, Size: 1459 bytes --]

There is an updated pull request by TinfoilSubmarine against master on the void-packages repository

https://github.com/TinfoilSubmarine/void-packages maint/synapse
https://github.com/void-linux/void-packages/pull/39416

[WIP] synapse: update to 1.68.0rc1.
build-style/python3-*.sh might need more adjusting for this, I already spotted
one problem where rustc consumes the TMPDIR environment variable and breaks the
build process.

<!-- Uncomment relevant sections and delete options which are not applicable -->

#### Testing the changes
- I tested the changes in this PR: **briefly**

<!--
#### New package
- This new package conforms to the [package requirements](https://github.com/void-linux/void-packages/blob/master/CONTRIBUTING.md#package-requirements): **YES**|**NO**
-->

<!-- Note: If the build is likely to take more than 2 hours, please add ci skip tag as described in
https://github.com/void-linux/void-packages/blob/master/CONTRIBUTING.md#continuous-integration
and test at least one native build and, if supported, at least one cross build.
Ignore this section if this PR is not skipping CI.
-->
<!--
#### Local build testing
- I built this PR locally for my native architecture, (ARCH-LIBC)
- I built this PR locally for these architectures (if supported. mark crossbuilds):
  - aarch64-musl
  - armv7l
  - armv6l-musl
-->


A patch file from https://github.com/void-linux/void-packages/pull/39416.patch is attached

[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: github-pr-maint/synapse-39416.patch --]
[-- Type: text/x-diff, Size: 4847 bytes --]

From f47163188071945a3bc46e56501483197af250d4 Mon Sep 17 00:00:00 2001
From: Joel Beckmeyer <joel@beckmeyer.us>
Date: Thu, 22 Sep 2022 08:55:24 -0400
Subject: [PATCH 1/3] python3-matrix-common: update to 1.3.0.

---
 srcpkgs/python3-matrix-common/template | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/srcpkgs/python3-matrix-common/template b/srcpkgs/python3-matrix-common/template
index 4ed002f4d2e6..0f71657b1a53 100644
--- a/srcpkgs/python3-matrix-common/template
+++ b/srcpkgs/python3-matrix-common/template
@@ -1,6 +1,6 @@
 # Template file for 'python3-matrix-common'
 pkgname=python3-matrix-common
-version=1.2.1
+version=1.3.0
 revision=1
 wrksrc="matrix-python-common-${version}"
 build_style=python3-pep517
@@ -11,5 +11,5 @@ maintainer="Joel Beckmeyer <joel@beckmeyer.us>"
 license="Apache-2.0"
 homepage="https://github.com/matrix-org/matrix-python-common"
 distfiles="https://github.com/matrix-org/matrix-python-common/archive/v${version}.tar.gz"
-checksum=75ccb0de5b5cd551d81770addea1d2b227831f9cb83d46079ee0c74af0fb0a69
+checksum=9792a69b04904cb2da027890fe07229cc6610254268d2a5037e31aaeb7047104
 make_check=no # requires unpackaged python3 module aiounittest

From b66d618eb7dfbbca90011efc87d2069f86dd8906 Mon Sep 17 00:00:00 2001
From: Joel Beckmeyer <joel@beckmeyer.us>
Date: Tue, 20 Sep 2022 14:16:45 -0400
Subject: [PATCH 3/3] synapse: update to 1.68.0rc1.

---
 srcpkgs/synapse/template | 15 ++++++++++-----
 1 file changed, 10 insertions(+), 5 deletions(-)

diff --git a/srcpkgs/synapse/template b/srcpkgs/synapse/template
index 307d3d08ade8..00ac93979931 100644
--- a/srcpkgs/synapse/template
+++ b/srcpkgs/synapse/template
@@ -1,11 +1,12 @@
 # Template file for 'synapse'
 pkgname=synapse
-version=1.67.0
+version=1.68.0rc1
 revision=1
 build_style=python3-pep517
+build_helper=rust
 make_check_target=tests
 make_install_target="matrix_synapse-${version}-*-*-*.whl"
-hostmakedepends="python3-poetry-core"
+hostmakedepends="python3-poetry-core python3-setuptools-rust cargo"
 depends="python3-jsonschema python3-frozendict python3-canonicaljson
  python3-signedjson python3-pynacl python3-service_identity python3-Twisted
  python3-openssl python3-yaml python3-pyasn1 python3-pyasn1-modules
@@ -14,7 +15,7 @@ depends="python3-jsonschema python3-frozendict python3-canonicaljson
  python3-setuptools python3-bleach python3-Jinja2 python3-psycopg2 python3-lxml
  python3-saml2 python3-treq python3-macaroons python3-sortedcontainers
  python3-typing_extensions python3-ijson python3-matrix-common
- python3-packaging python3-pydantic"
+ python3-packaging python3-pydantic python3-setuptools-rust"
 checkdepends="$depends python3-parameterized unzip"
 short_desc="Matrix reference homeserver"
 maintainer="Joel Beckmeyer <joel@beckmeyer.us>"
@@ -22,7 +23,11 @@ license="Apache-2.0"
 homepage="https://github.com/matrix-org/synapse"
 changelog="https://raw.githubusercontent.com/matrix-org/synapse/develop/CHANGES.md"
 distfiles="https://github.com/matrix-org/synapse/archive/v${version}.tar.gz"
-checksum=85eeb24890c4b8e68f1e5ca4d5e69e1eb49e67cc33c450dc7c1fe7e70c023c68
+checksum=a05f7ac82c8ee2bd7b7d24c01a040d234be2e7c2e1e24a1156b86d71a9352647
+
+if [ "$CROSS_BUILD" ]; then
+	makedepends+=" rust-std"
+fi
 
 system_accounts="synapse"
 synapse_homedir="/var/lib/synapse"
@@ -37,7 +42,7 @@ pre_check() {
 }
 
 do_check() {
-	PYTHONPATH="." trial3 ${makejobs} tests
+	PYTHONPATH=. trial3 ${makejobs} tests
 }
 
 post_install() {

  parent reply	other threads:[~2022-09-22 14:30 UTC|newest]

Thread overview: 23+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-09-22 14:20 [PR PATCH] [WIP] synapse: update to 1.68.0rc1. New package: python3-setuptools_rust-1.5.2 TinfoilSubmarine
2022-09-22 14:21 ` ahesford
2022-09-22 14:21 ` [PR PATCH] [Updated] " TinfoilSubmarine
2022-09-22 14:23 ` TinfoilSubmarine
2022-09-22 14:26 ` [WIP] synapse: update to 1.68.0rc1 ahesford
2022-09-22 14:28 ` TinfoilSubmarine
2022-09-22 14:30 ` TinfoilSubmarine [this message]
2022-09-22 14:37 ` TinfoilSubmarine
2022-09-23 12:12 ` [PR PATCH] [Updated] " TinfoilSubmarine
2022-09-23 12:40 ` [PR PATCH] [Updated] [WIP] synapse: update to 1.68.0rc2 TinfoilSubmarine
2022-09-26 14:55 ` TinfoilSubmarine
2022-09-26 14:56 ` [PR REVIEW] " ahesford
2022-09-26 14:56 ` ahesford
2022-09-26 14:56 ` ahesford
2022-09-26 14:56 ` ahesford
2022-09-26 14:56 ` ahesford
2022-09-26 14:56 ` ahesford
2022-09-26 15:49 ` TinfoilSubmarine
2022-09-26 16:07 ` ahesford
2022-09-26 16:27 ` [PR PATCH] [Updated] " TinfoilSubmarine
2022-09-26 16:38 ` [PR REVIEW] " TinfoilSubmarine
2022-09-27 12:44 ` [PR PATCH] [Updated] " TinfoilSubmarine
2022-09-28 14:41 ` [PR PATCH] [Closed]: synapse: update to 1.68.0 ahesford

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220922143026.eVHuaacIDc0Ug9i2ym5cOYlqvMO_XJeJMzw_Mw8SJWg@z \
    --to=tinfoilsubmarine@users.noreply.github.com \
    --cc=ml@inbox.vuxu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).
From bc2d1590b15a99f627d66aa6917bda2bb13ae27b Mon Sep 17 00:00:00 2001
From: Joel Beckmeyer <joel@beckmeyer.us>
Date: Thu, 22 Sep 2022 10:06:13 -0400
Subject: [PATCH 2/3] common/build-style/python3-pep517.sh: use TMP instead of
 TMPDIR

avoids side effects with setuptools_rust / rustc
---
 common/build-style/python3-pep517.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/common/build-style/python3-pep517.sh b/common/build-style/python3-pep517.sh
index 1eeb4172492e..1d6478388a32 100644
--- a/common/build-style/python3-pep517.sh
+++ b/common/build-style/python3-pep517.sh
@@ -8,7 +8,7 @@ do_build() {
 	: ${make_build_target:=.}
 
 	mkdir -p build
-	TMPDIR=build python3 -m pip wheel --no-deps --use-pep517 --no-clean \
+	TMP=build python3 -m pip wheel --no-deps --use-pep517 --no-clean \
 		--no-build-isolation ${make_build_args} ${make_build_target}
 }
 
@@ -33,9 +33,9 @@ do_install() {
 		make_install_target="${wheelbase//-/_}-${version}-*-*-*.whl"
 	fi
 
 	# If do_build was overridden, make sure the TMPDIR exists
 	mkdir -p build
-	TMPDIR=build python3 -m pip install --use-pep517 --prefix /usr \
+	TMP=build python3 -m pip install --use-pep517 --prefix /usr \
 		--root ${DESTDIR} --no-deps --no-build-isolation \
 		--no-clean ${make_install_args} ${make_install_target}
 }
@@ -33,9 +33,9 @@ do_install() {
 	fi
 
-	# If do_build was overridden, make sure the TMPDIR exists
+	# If do_build was overridden, make sure the TMP exists
 	mkdir -p build
